@@ -15,7 +15,7 @@ def main():
 
     for info in config.pdf_files:
         root = config.root_path
-        pdf_file = info['path']
+        pdf_file = os.path.join(root, info['path'])
         png_files = info['pages']
         titles = info['titles']
         PDF_to_PNG(pdf_file, png_files)
@@ -27,4 +27,4 @@ def main():
 
 
 if __name__ == '__main__':
-    main()
\ No newline at end of file
+    main()
